# lazyprint
Earlier I was a Java lover. In Java, I didn't loved much the System.out.print() again and again. So, I used sop instead.

When I started coding in python. Being a lazy coder, I want a p() to be used insted of print() because I need to test output of programs many times. And, writing print many times make me slow. So, here is a simple package to use 'p()' instead of 'print()'
#usage
from lazyprint import p
p("Hello, World!")

## Installation
```sh
pip install lazyprint


